==> jc-1.4.0.tar.gz: gnu/xml/pipeline/LinkFilter.h <==
// public class gnu.xml.pipeline.LinkFilter

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class 24556a4025af9de1 gnu_xml_pipeline_LinkFilter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_pipeline_LinkFilter_H_
#define _JC_gnu_xml_pipeline_LinkFilter_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Vector$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_LinkFilter$sub_refs	_jc_gnu_xml_pipeline_LinkFilter$sub_refs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs	_jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$refs	_jc_gnu_xml_pipeline_LinkFilter$refs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$nonrefs	_jc_gnu_xml_pipeline_LinkFilter$nonrefs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$object	_jc_gnu_xml_pipeline_LinkFilter$object;

typedef const struct _jc_gnu_xml_pipeline_LinkFilter$vmethods	_jc_gnu_xml_pipeline_LinkFilter$vmethods;
typedef const struct _jc_gnu_xml_pipeline_LinkFilter$vtable	_jc_gnu_xml_pipeline_LinkFilter$vtable;
typedef const struct _jc_gnu_xml_pipeline_LinkFilter$vtype	_jc_gnu_xml_pipeline_LinkFilter$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_LinkFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
extern void _jc_gnu_xml_pipeline_LinkFilter$method$_init$f55e1e8bd1cec8e3(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_xml_pipeline_LinkFilter$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
extern struct _jc_object *_jc_gnu_xml_pipeline_LinkFilter$method$getLinks$d93fa1478c933255(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_LinkFilter$method$maybeAddLink$9e949fe0ed558164(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_pipeline_LinkFilter$method$removeAllLinks$4af27dfa4aff5036(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
extern void _jc_gnu_xml_pipeline_LinkFilter$method$startDocument$00c72777de6ab226(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
extern void _jc_gnu_xml_pipeline_LinkFilter$method$startElement$f49f2a9a9ee4885f(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_gnu_xml_pipeline_LinkFilter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$endDocument$4903a775f2613143;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$getLinks$d93fa1478c933255;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$maybeAddLink$9e949fe0ed558164;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$removeAllLinks$4af27dfa4aff5036;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$startDocument$00c72777de6ab226;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$startElement$f49f2a9a9ee4885f;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_LinkFilter$vmethods {
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
	struct _jc_object	*(*getLinks$d93fa1478c933255)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
	struct _jc_java_lang_String$object	*(*maybeAddLink$9e949fe0ed558164)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *);
	void	(*removeAllLinks$4af27dfa4aff5036)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
	void	(*startDocument$00c72777de6ab226)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
	void	(*startElement$f49f2a9a9ee4885f)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_LinkFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_pipeline_LinkFilter$vmethods	gnu_xml_pipeline_LinkFilter;
};

// Vtype
struct _jc_gnu_xml_pipeline_LinkFilter$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_LinkFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_LinkFilter$sub_refs {
	struct _jc_java_util_Vector$object	*vector;
	struct _jc_java_lang_String$object	*baseURI;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_LinkFilter$refs {
    _jc_gnu_xml_pipeline_LinkFilter$sub_refs	gnu_xml_pipeline_LinkFilter;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs {
	jboolean	siteRestricted;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_LinkFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs	gnu_xml_pipeline_LinkFilter;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_LinkFilter$object {
	_jc_gnu_xml_pipeline_LinkFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_LinkFilter$vtype	*vtype;
	_jc_gnu_xml_pipeline_LinkFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_LinkFilter$vtype _jc_gnu_xml_pipeline_LinkFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_LinkFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_LinkFilter$class_object;

#endif	/* _JC_gnu_xml_pipeline_LinkFilter_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/LinkFilter.h <==
// public class gnu.xml.pipeline.LinkFilter

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class 24556a4025af9de1 gnu_xml_pipeline_LinkFilter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_pipeline_LinkFilter_H_
#define _JC_gnu_xml_pipeline_LinkFilter_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Vector$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_LinkFilter$sub_refs	_jc_gnu_xml_pipeline_LinkFilter$sub_refs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs	_jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$refs	_jc_gnu_xml_pipeline_LinkFilter$refs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$nonrefs	_jc_gnu_xml_pipeline_LinkFilter$nonrefs;
typedef struct _jc_gnu_xml_pipeline_LinkFilter$object	_jc_gnu_xml_pipeline_LinkFilter$object;

typedef const struct _jc_gnu_xml_pipeline_LinkFilter$vmethods	_jc_gnu_xml_pipeline_LinkFilter$vmethods;
typedef const struct _jc_gnu_xml_pipeline_LinkFilter$vtable	_jc_gnu_xml_pipeline_LinkFilter$vtable;
typedef const struct _jc_gnu_xml_pipeline_LinkFilter$vtype	_jc_gnu_xml_pipeline_LinkFilter$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_LinkFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_LinkFilter$method$_init$f55e1e8bd1cec8e3(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_pipeline_LinkFilter$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_pipeline_LinkFilter$method$getLinks$d93fa1478c933255(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_LinkFilter$method$maybeAddLink$9e949fe0ed558164(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_LinkFilter$method$removeAllLinks$4af27dfa4aff5036(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_LinkFilter$method$startDocument$00c72777de6ab226(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_LinkFilter$method$startElement$f49f2a9a9ee4885f(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_LinkFilter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$endDocument$4903a775f2613143;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$getLinks$d93fa1478c933255;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$maybeAddLink$9e949fe0ed558164;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$removeAllLinks$4af27dfa4aff5036;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$startDocument$00c72777de6ab226;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$startElement$f49f2a9a9ee4885f;
extern _jc_method _jc_gnu_xml_pipeline_LinkFilter$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_LinkFilter$vmethods {
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLinks$d93fa1478c933255)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*maybeAddLink$9e949fe0ed558164)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*removeAllLinks$4af27dfa4aff5036)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
	void	(*startDocument$00c72777de6ab226)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
	void	(*startElement$f49f2a9a9ee4885f)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_pipeline_LinkFilter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_LinkFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_pipeline_LinkFilter$vmethods	gnu_xml_pipeline_LinkFilter;
};

// Vtype
struct _jc_gnu_xml_pipeline_LinkFilter$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_LinkFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_LinkFilter$sub_refs {
	struct _jc_java_util_Vector$object	*vector;
	struct _jc_java_lang_String$object	*baseURI;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_LinkFilter$refs {
    _jc_gnu_xml_pipeline_LinkFilter$sub_refs	gnu_xml_pipeline_LinkFilter;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs {
	jboolean	siteRestricted;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_LinkFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_pipeline_LinkFilter$sub_nonrefs	gnu_xml_pipeline_LinkFilter;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_LinkFilter$object {
	_jc_gnu_xml_pipeline_LinkFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_LinkFilter$vtype	*vtype;
	_jc_gnu_xml_pipeline_LinkFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_LinkFilter$vtype _jc_gnu_xml_pipeline_LinkFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_LinkFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_LinkFilter$class_object;

#endif	/* _JC_gnu_xml_pipeline_LinkFilter_H_ */
